@@ -1,11 +1,11 @@
 import shutil
-from datetime import datetime, time, timezone
+from datetime import datetime, time
 from distutils.dir_util import copy_tree
 from http.server import SimpleHTTPRequestHandler
 from multiprocessing import Pool
 from pathlib import Path
 
-from feedgen.feed import FeedGenerator
+from dateutil import tz
 from jinja2 import Environment, FileSystemLoader
 
 from kart.markdown import markdown_to_html, markdown_to_toc
@@ -34,9 +34,11 @@ class DefaultRenderer(Renderer):
         for page in map.values():
             if page["renderer"] != self.name:
                 continue
+            rendered_file = self.render_single(page, map, site)
             path = Path(build_location) / Path(*Path(page["url"]).parts[1:])
+            path.parent.mkdir(parents=True, exist_ok=True)
             with path.open("w") as f:
-                f.write(self.render_single(page, map, site))
+                f.write(rendered_file)
 
     def serve(self, http_handler, page, map, site):
         http_handler.send_response(200)
@@ -78,12 +80,11 @@ class DefaultSiteRenderer(DefaultRenderer):
         if page["renderer"] != self.name:
             return
         rendered_file = self.render_single(page, map, site)
-        if rendered_file:
-            path = Path(build_location) / Path(*Path(page["url"]).parts[1:])
-            path = path / "index.html"
-            path.parent.mkdir(parents=True, exist_ok=True)
-            with path.open("w") as f:
-                f.write(rendered_file)
+        path = Path(build_location) / Path(*Path(page["url"]).parts[1:])
+        path = path / "index.html"
+        path.parent.mkdir(parents=True, exist_ok=True)
+        with path.open("w") as f:
+            f.write(rendered_file)
 
     def render(self, map, site, build_location="_site"):
         if self.process_count == 1:
@@ -102,32 +103,33 @@ class DefaultFeedRenderer(DefaultRenderer):
         self.content_type = "application/xml"
 
     def render_single(self, page, map, site):
-        base_url = site["config"]["base_url"]
-        fg = FeedGenerator()
-        fg.title(site["config"]["name"])
-        if not base_url:
-            fg.id("base_url/")
-        else:
-            fg.id(base_url)
-        fg.link({"href": base_url})
-        fg.link({"href": base_url + "/atom.xml", "rel": "self"})
         feed_entries = []
         for collection in page["data"]["collections"]:
             for object in site[collection].values():
-                feed_entries.append([collection, object])
-        feed_entries.sort(key=lambda x: x[1]["date"])
-        for collection, entry in feed_entries:
-            fe = fg.add_entry()
-            if "title" in entry.keys():
-                fe.title(entry["title"])
-            elif "name" in entry.keys():
-                fe.title(entry["name"])
+                feed_entries.append([map.url(collection, object["slug"]), object])
+        feed_entries.sort(key=lambda x: x[1]["date"], reverse=True)
+        atom = '<feed xmlns="http://www.w3.org/2005/Atom">'
+        atom += f'<id>"{map.url("/")}"</id>'
+        atom += f"<title>{site['config']['name']}</title>"
+        timezone = site["config"]["timezone"]
+        updated_time = datetime.now().replace(tzinfo=tz.gettz(timezone))
+        atom += f"<updated>{updated_time.isoformat()}</updated>"
+        atom += f'<link href="{map.url("/")}"/>'
+        atom += f'<link href="{map.url(page["url"])}" rel="self"/>'
+        for url, entry in feed_entries:
+            atom += "<entry>"
+            atom += f"<id>{url}</id>"
+            title = entry["title"] if "title" in entry.keys() else entry["name"]
+            atom += f"<title>{title}</title>"
+            entry_time = datetime.combine(entry["date"], time(12))
+            entry_time.replace(tzinfo=tz.gettz(timezone))
+            atom += f"<updated>{entry_time.isoformat()}</updated>"
             if "description" in entry.keys():
-                fe.description(entry["description"])
-            fe.updated(datetime.combine(entry["date"], time(12), tzinfo=timezone.utc))
-            fe.id(map.url(collection, entry["slug"]))
-            fe.link({"href": map.url(collection, entry["slug"])})
-        return fg.atom_str().decode()
+                atom += f'<summary>{entry["description"]}</summary>'
+            atom += f'<link href="{url}" link="alternate"/>'
+            atom += "</entry>"
+        atom += "</feed>"
+        return atom
 
 
 class DefaultSitemapRenderer(DefaultRenderer):
