@@ -39,14 +39,15 @@ class KartMap(UserDict):
         if not name:
             return ""
         if name in self.data.keys():
-            result = self.data[name]["url"]
+            return self.base_url + self.data[name]["url"]
         elif name + ".1" in self.data.keys():
-            result = self.data[name + ".1"]["url"]
+            return self.base_url + self.data[name + ".1"]["url"]
+        elif "http" in name:
+            return name
         elif "/" in name:
-            result = name
-        else:
-            return ""
-        return self.base_url + result
+            return self.base_url + name
+        print("Invalid url")
+        return ""
 
 
 def paginate(objects, per_page, template, base_url, slug, additional_data={}):
@@ -56,27 +57,27 @@ def paginate(objects, per_page, template, base_url, slug, additional_data={}):
         for x in range(max(math.ceil(len(objects) / per_page), 1))
     ]
     for i, objects in enumerate(paginated_objects, 1):
-        url = f"/{i}/" if i > 1 else "/"
-        if i > 2:
-            previous_page_url = base_url + f"/{i-1}/"
-        elif i == 2:
-            previous_page_url = base_url + "/"
+
+        if i > 1:
+            previous_page = f"{slug}.{i-1}"
         else:
-            previous_page_url = ""
+            previous_page = ""
+
         if i < len(paginated_objects):
-            next_page_url = base_url + f"/{i+1}/"
+            next_page = f"{slug}.{i+1}"
         else:
-            next_page_url = ""
+            next_page = ""
+
         paginator = {
             "objects": objects,
             "index": i,
-            "next_page_url": next_page_url,
-            "previous_page_url": previous_page_url,
+            "next_page": next_page,
+            "previous_page": previous_page,
         }
         data = {"paginator": paginator}
         data.update(additional_data)
         urls[f"{slug}.{i}"] = {
-            "url": base_url + url,
+            "url": base_url + f"/{i}/" if i > 1 else base_url,
             "data": data,
             "template": template,
             "renderer": "default_site_renderer",
